<?xml version="1.0"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns="http://www.w3.org/1999/xhtml" xmlns:xhtml="http://www.w3.org/1999/xhtml">
	<xsl:output method="xml"
							media-type="text/xml"
							doctype-system="include/xhtml-math-svg-flat.dtd"
							doctype-public="-//W3C//DTD XHTML 1.1 plus MathML 2.0 plus SVG 1.1//EN"
							encoding="UTF-8"
							indent="no"/>
	<xsl:output name="text"
							method="text"
							media-type="text/plain"
							encoding="ISO-8859-1"/>  
												
	<xsl:param name="include-optional-paragraphs" select="Yes"/>			

<!-- ******************************************************************************************** 
		 MiLCA XSLT Stylesheet zur leichteren Ueberfuehrung nach ILIAS 
		 Fragen und Anregungen: Maik Stuehrenberg, JLU Giessen 
		 maik.stuehrenberg@uni-giessen.de
		 zuletzt geaendert am: 08-07-2003, 11:30
		 Copyright (c) 2003 Maik Stührenberg (JLU Gießen).
	 	 Permission is granted to copy, distribute and/or modify this document under the terms of the GNU Free Documentation License, Version 1.2 or any later version published by the Free Software Foundation;
     with no Invariant Sections, no Front-Cover Texts, and no Back-Cover Texts.
     A copy of the license is included in the file entitled "fdl.txt".
		 ******************************************************************************************** -->

	<xsl:strip-space elements="*"/>
	<xsl:preserve-space elements="xsl:text"/>

<!-- Template fuer das root-Element LearningObject -->
<!-- Die Verarbeitung erfolgt in mehreren Schritten: -->
<!-- 1. Erzeugung einer Ausgabedatei -->
<!-- 2. Erstellung eines Inhaltsverzeichnisses -->
<!-- Dabei wird jeweils dem AggregationLevel unterschieden -->
	<xsl:template match="LearningObject">
		<xsl:choose>
			<xsl:when test="MetaData/General/@AggregationLevel>=3">
<!-- Level 3 und hoeher erhalten ein Inhaltsverzeichnis -->			
				<xsl:variable name="index" select="concat(string(MetaData/General/Identifier/@Entry),'.xhtml')"/>
				<xsl:result-document href="{$index}">
					<html>
						<head>
							<xsl:apply-templates select="MetaData"/>
						</head>
						<body>
							<h1>
								<xsl:value-of select="MetaData/General/Title"/>
							</h1>
							<p>
								<xsl:choose>
									<xsl:when test="MetaData/General/Language='de'">
										<b>Zusammenfassung:</b>
									</xsl:when>
									<xsl:when test="MetaData/General/Language='en'">
										<b>Abstract:</b>
									</xsl:when>
									<xsl:otherwise>
										<b>Abstract:</b>
									</xsl:otherwise>
								</xsl:choose>
								<br/>
								<xsl:apply-templates select="MetaData/General/Description"/>
							</p>
<!-- Erzeugen des Inhaltsverzeichnisses -->
<!-- Jedes LearningObject mit einem AggregationLevel > 1 wird in das Inhaltsverzeichnis aufgenommen -->					
							<xsl:choose>
								<xsl:when test="MetaData/General/Language='de'">
									<h2>Inhalt</h2>
								</xsl:when>
								<xsl:when test="MetaData/General/Language='en'">
									<h2>Table of Contents</h2>
								</xsl:when>
								<xsl:otherwise>
									<h2>Table of Contents</h2>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:for-each select="Content/LearningObject">
								<xsl:choose>
									<xsl:when test="MetaData/General/@AggregationLevel>1">
										<xsl:variable name="LOfile" select="concat(string(MetaData/General/Identifier/@Entry),'.xhtml')"/>
										<p>
											<a>
												<xsl:attribute name="href">	
													<xsl:value-of select="$LOfile"/>
												</xsl:attribute>
												<xsl:value-of select="MetaData/General/Title"/>
											</a>
											<br/>
											<xsl:apply-templates select="MetaData/General/Description"/>
										</p>								
									</xsl:when>
								</xsl:choose>
							</xsl:for-each>
							<xsl:if test="Test | Bibliography | Glossary">
								<br/>
							</xsl:if>
							<xsl:apply-templates select="Test"/>
							<xsl:if test="Bibliography">
								<p>
									<a>
										<xsl:attribute name="href">
											<xsl:value-of select="concat(string(MetaData/General/Identifier/@Entry),'-','bib','.xhtml')"/>
										</xsl:attribute>
										<xsl:choose>
											<xsl:when test="MetaData/General/Language='de'">
												Literaturangaben
											</xsl:when>
											<xsl:otherwise>
												Bibliography
											</xsl:otherwise>
										</xsl:choose>
									</a>
								</p>
								<xsl:apply-templates select="Bibliography"/>
							</xsl:if>											
							<xsl:if test="Glossary">								
								<p>
									<a>
										<xsl:attribute name="href">
											<xsl:value-of select="concat(string(MetaData/General/Identifier/@Entry),'-','gloss','.xhtml')"/>
										</xsl:attribute>
										<xsl:choose>
											<xsl:when test="MetaData/General/Language='de'">
												Glossar
											</xsl:when>
											<xsl:otherwise>
												Glossary
											</xsl:otherwise>
										</xsl:choose>
									</a>
								</p>
								<xsl:apply-templates select="Glossary"/>
							</xsl:if>
						</body>
					</html>
				</xsl:result-document>
			</xsl:when>
			<xsl:when test="MetaData/General/@AggregationLevel=2">
<!-- LearningObjects mit Level 2 werden als HTML-Seiten ausgegeben -->			
				<xsl:variable name="LO" select="concat(string(MetaData/General/Identifier/@Entry),'.xhtml')"/>
				<xsl:result-document href="{$LO}">
					<html>
						<head>
							<xsl:apply-templates select="MetaData"/>
						</head>
						<body>
<!-- Einfuegen eines Kommentars, damit das Einfuegen in ILIAS per Cut/Paste schneller geht -->			
							<xsl:comment>Ab hier ausschneiden und in ILIAS einfuegen wenn Description erwuenscht!</xsl:comment>
							<h1>
								<xsl:value-of select="MetaData/General/Title"/>
							</h1>
							<p>
								<xsl:choose>
									<xsl:when test="MetaData/General/Language='de'">
										<b>Zusammenfassung:</b>
									</xsl:when>
									<xsl:when test="MetaData/General/Language='en'">
										<b>Abstract:</b>
									</xsl:when>
									<xsl:otherwise>
										<b>Abstract:</b>
									</xsl:otherwise>
								</xsl:choose>
								<br/>
								<xsl:apply-templates select="MetaData/General/Description"/>
							</p>
							<xsl:comment>Ab hier ausschneiden und in ILIAS einfuegen!</xsl:comment>
							<xsl:apply-templates select="Content"/>
							<xsl:if test="Test | Bibliography | Glossary">
								<br/>
							</xsl:if>
							<xsl:apply-templates select="Test"/>
							<xsl:if test="Bibliography">
								<p>
									<a>
										<xsl:attribute name="href">
											<xsl:value-of select="concat(string(MetaData/General/Identifier/@Entry),'-','bib','.xhtml')"/>
										</xsl:attribute>
										<xsl:choose>
											<xsl:when test="MetaData/General/Language='de'">
												Literaturangaben
											</xsl:when>
											<xsl:otherwise>
												Bibliography
											</xsl:otherwise>
										</xsl:choose>
									</a>
								</p>
								<xsl:apply-templates select="Bibliography"/>
							</xsl:if>
							<xsl:if test="Glossary">
								<p>
									<a>
										<xsl:attribute name="href">
											<xsl:value-of select="concat(string(MetaData/General/Identifier/@Entry),'-','gloss','.xhtml')"/>
										</xsl:attribute>
										<xsl:choose>
											<xsl:when test="MetaData/General/Language='de'">
												Glossar
											</xsl:when>
											<xsl:otherwise>
												Glossary
											</xsl:otherwise>
										</xsl:choose>
									</a>
								</p>
								<xsl:apply-templates select="Glossary"/>
							</xsl:if>
							<xsl:comment>Hier Ende von Cut/Paste fuer ILIAS!</xsl:comment>								
						</body>
					</html>
				</xsl:result-document>
			</xsl:when>
			<xsl:when test="MetaData/General/@AggregationLevel=1">
				<xsl:comment>Ab hier Objekt &quot;<xsl:value-of select="MetaData/Technical/Location"/>&quot;!</xsl:comment>
				<xsl:choose>
<!-- GIF Images -->				
					<xsl:when test="MetaData/Technical/@Format='image-gif'">
						<img>
							<xsl:attribute name="src">
								<xsl:value-of select="MetaData/Technical/Location"/>
							</xsl:attribute>
							<xsl:attribute name="alt">
								<xsl:value-of select="MetaData/General/Description"/>
							</xsl:attribute>
						</img>
						<xsl:comment>Ende des Objekts &quot;<xsl:value-of select="MetaData/Technical/Location"/>&quot;!</xsl:comment>
						<div style="font-family:verdana,arial,sans-serif; font-weight:bold; font-size:smaller;">
							<xsl:choose>
								<xsl:when test="MetaData/General/Language='de'">
									<xsl:text>Abbildung </xsl:text>
								</xsl:when>
								<xsl:otherwise>
									<xsl:text>Figure </xsl:text>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:number count="LearningObject"/>
							<xsl:text>: </xsl:text>
							<xsl:value-of select="MetaData/General/Title"/>
						</div>
						<div style="font-family:verdana,arial,sans-serif; font-size:smaller;">
							<xsl:apply-templates select="MetaData/General/Description"/>
						</div>
					</xsl:when>
<!-- JPEG Images -->					
					<xsl:when test="MetaData/Technical/@Format='image-jpeg'">
						<img>
							<xsl:attribute name="src">
								<xsl:value-of select="MetaData/Technical/Location"/>
							</xsl:attribute>
							<xsl:attribute name="alt">
								<xsl:value-of select="MetaData/General/Description"/>
							</xsl:attribute>
						</img>
						<xsl:comment>Ende des Objekts &quot;<xsl:value-of select="MetaData/Technical/Location"/>&quot;!</xsl:comment>
						<div style="font-family:verdana,arial,sans-serif; font-weight:bold; font-size:smaller;">
							<xsl:choose>
								<xsl:when test="MetaData/General/Language='de'">
									<xsl:text>Abbildung </xsl:text>
								</xsl:when>
								<xsl:otherwise>
									<xsl:text>Figure </xsl:text>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:number count="LearningObject"/>
							<xsl:text>: </xsl:text>
							<xsl:value-of select="MetaData/General/Title"/>
						</div>
						<div style="font-family:verdana,arial,sans-serif; font-size:smaller;">
							<xsl:apply-templates select="MetaData/General/Description"/>
						</div>
					</xsl:when>
<!-- PNG Images -->					
					<xsl:when test="MetaData/Technical/@Format='image-png'">
						<img>
							<xsl:attribute name="src">
								<xsl:value-of select="MetaData/Technical/Location"/>
							</xsl:attribute>
							<xsl:attribute name="alt">
								<xsl:value-of select="MetaData/General/Description"/>
							</xsl:attribute>
						</img>
						<xsl:comment>Ende des Objekts &quot;<xsl:value-of select="MetaData/Technical/Location"/>&quot;!</xsl:comment>
						<div style="font-family:verdana,arial,sans-serif; font-weight:bold; font-size:smaller;">
							<xsl:choose>
								<xsl:when test="MetaData/General/Language='de'">
									<xsl:text>Abbildung </xsl:text>
								</xsl:when>
								<xsl:otherwise>
									<xsl:text>Figure </xsl:text>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:number count="LearningObject"/>
							<xsl:text>: </xsl:text>
							<xsl:value-of select="MetaData/General/Title"/>
						</div>
						<div style="font-family:verdana,arial,sans-serif; font-size:smaller;">
							<xsl:apply-templates select="MetaData/General/Description"/>
						</div>
					</xsl:when>
<!-- SVG Images - muessen umgewandelt werden -->					
					<xsl:when test="MetaData/Technical/@Format='image-svg-xml'">
						<xsl:copy-of select="document(MetaData/Technical/Location)/*"/>
						<xsl:comment>Ende des Objekts &quot;<xsl:value-of select="MetaData/Technical/Location"/>&quot;!</xsl:comment>
						<div style="font-family:verdana,arial,sans-serif; font-weight:bold; font-size:smaller;">
							<xsl:choose>
								<xsl:when test="MetaData/General/Language='de'">
									<xsl:text>Abbildung </xsl:text>
								</xsl:when>
								<xsl:otherwise>
									<xsl:text>Figure </xsl:text>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:number count="LearningObject"/>
							<xsl:text>: </xsl:text>
							<xsl:value-of select="MetaData/General/Title"/>
						</div>
						<div style="font-family:verdana,arial,sans-serif; font-size:smaller;">
							<xsl:apply-templates select="MetaData/General/Description"/>
						</div>
					</xsl:when>
<!-- Imagemaps -->					
					<xsl:when test="MetaData/Technical/@Format='text-xhtml'">
						<xsl:copy-of select="document(MetaData/Technical/Location)/xhtml:html/xhtml:body/*"/>
						<xsl:comment>Ende des Objekts &quot;<xsl:value-of select="MetaData/Technical/Location"/>&quot;!</xsl:comment>
						<div style="font-family:verdana,arial,sans-serif; font-weight:bold; font-size:smaller;">
							<xsl:value-of select="MetaData/General/Title"/>
						</div>
						<div style="font-family:verdana,arial,sans-serif; font-size:smaller;">
							<xsl:apply-templates select="MetaData/General/Description"/>
						</div>
					</xsl:when>
					<xsl:otherwise>
						<a>
							<xsl:attribute name="href">
								<xsl:value-of select="MetaData/Technical/Location"/>
							</xsl:attribute>
							<xsl:value-of select="MetaData/General/Title"/>
						</a>
					</xsl:otherwise>								
				</xsl:choose>
			</xsl:when>
		</xsl:choose>
		<xsl:apply-templates/>
	</xsl:template>
	
<!-- Template fuer die MetaDaten -->
<!-- In HTML verwendete MetaDaten wie Titel, Autor, Description und Keywords werden weitergerreicht -->
	<xsl:template match="MetaData">
		<xsl:for-each select="Lifecycle/Contribute/Entity">
			<xsl:if test="@Role='Author'">
				<meta name="author">
					<xsl:attribute name="content">
						<xsl:choose>
							<xsl:when test="vCard">
								<xsl:value-of select="vCard/FN"/>		
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</meta>
			</xsl:if>
		</xsl:for-each>
		<xsl:if test="General/@AggregationLevel>1">
			<meta name="description">
				<xsl:attribute name="content">
					<xsl:value-of select="General/Description"/>
				</xsl:attribute>
			</meta>
			<meta name="keywords">
				<xsl:attribute name="content">
					<xsl:for-each select="General/Keyword">
						<xsl:value-of select="."/>
						<xsl:if test="position()!=last()">
							<xsl:text>, </xsl:text>
						</xsl:if>
					</xsl:for-each>
				</xsl:attribute>
			</meta>
			<title>
				<xsl:value-of select="General/Title"/>
			</title>
		</xsl:if>
	</xsl:template>
	
<!-- Template fuer den Inhalt -->
	<xsl:template match="Content">
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="Text">
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="Paragraph">
		<xsl:choose>
			<xsl:when test="$include-optional-paragraphs='No' and @Optional='Yes'">
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="@Characteristic='Headline'">
						<h3><xsl:apply-templates/></h3>
					</xsl:when>
					<xsl:when test="@Characteristic='Mnemonic'">
						<div style="margin-left:20%; margin-right:20%; margin-top:15px; padding:10px; font-family:verdana,arial,sans-serif; font-weight:bold; background-color:#cccccc; border-style:solid; border-color:black; border-width:2;">
							<xsl:choose>
								<xsl:when test="../../../MetaData/General/Language='de'">
									Zusammenfassung:
								</xsl:when>
								<xsl:otherwise>
									Abstract:
								</xsl:otherwise>
							</xsl:choose>
							<br/>
							<xsl:apply-templates/>
						</div>
					</xsl:when>
					<xsl:otherwise>
						<xsl:choose>
							<xsl:when test="Table">
								<xsl:apply-templates/>
							</xsl:when>
							<xsl:otherwise>
								<p>
									<xsl:apply-templates/>
								</p>		
							</xsl:otherwise>
						</xsl:choose>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="Link">
		<a target="_blank">
			<xsl:attribute name="href">
 				<xsl:value-of select="@Href"/>
 			</xsl:attribute>
 			<xsl:attribute name="title">
 				<xsl:value-of select="@Title"/>
 			</xsl:attribute>
 			<xsl:apply-templates/>
		</a>
	</xsl:template>
	
<!-- Emph und Strong werden nach HTML durchgereicht -->
<!-- Je nach Grund der Hervorhebung wird eine CSS-Klasse genutzt -->
	<xsl:template match="Emph">
		<em>
			<xsl:choose>
				<xsl:when test="@Reason='Keyword'">
					<xsl:attribute name="class">
						<xsl:text>Keyword</xsl:text>
					</xsl:attribute>
					<xsl:apply-templates/>
				</xsl:when>
				<xsl:when test="@Reason='Intuition'">
					<xsl:attribute name="class">
						<xsl:text>Intuition</xsl:text>
					</xsl:attribute>
					<xsl:apply-templates/>
				</xsl:when>
				<xsl:when test="@Reason='MetaLanguageUse'">
					<xsl:attribute name="class">
						<xsl:text>MetaLanguageUse</xsl:text>
					</xsl:attribute>
					<xsl:apply-templates/>
				</xsl:when>
				<xsl:when test="@Reason='Highlight'">
					<xsl:attribute name="class">
						<xsl:text>Highlight</xsl:text>
					</xsl:attribute>
					<xsl:apply-templates/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates/>
				</xsl:otherwise>
			</xsl:choose>
		</em>
 	</xsl:template>
 	
 	<xsl:template match="Strong">
 		<strong>
 			<xsl:choose>
				<xsl:when test="@Reason='Keyword'">
					<xsl:attribute name="class">
						<xsl:text>Keyword</xsl:text>
					</xsl:attribute>
					<xsl:apply-templates/>
				</xsl:when>
				<xsl:when test="@Reason='Intuition'">
					<xsl:attribute name="class">
						<xsl:text>Intuition</xsl:text>
					</xsl:attribute>
					<xsl:apply-templates/>
				</xsl:when>
				<xsl:when test="@Reason='MetaLanguageUse'">
					<xsl:attribute name="class">
						<xsl:text>MetaLanguageUse</xsl:text>
					</xsl:attribute>
					<xsl:apply-templates/>
				</xsl:when>
				<xsl:when test="@Reason='Highlight'">
					<xsl:attribute name="class">
						<xsl:text>Highlight</xsl:text>
					</xsl:attribute>
					<xsl:apply-templates/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates/>
				</xsl:otherwise>
			</xsl:choose>
 		</strong>
 	</xsl:template>
 	
<!-- Woertliche Zitate -->
<!-- Zitate werden in Anfuehrungszeichen gesetzt -->
<!-- Wenn es eine Referenz gibt, dann wird der Autor der Referenz genannt -->
<!-- Gibt es mehrere Autoren, werden sie durch Kommata getrennt -->
<!-- Anschliessend erfolgt die Nennung des Jahres und einer evtl. vorhandenen Seitenangabe --> 
 	<xsl:template match="Quotation">
 		<xsl:choose>
 			<xsl:when test="@Type='Block'">
				<blockquote>
					<xsl:text>"</xsl:text>
					<xsl:apply-templates/>
					<xsl:text>" </xsl:text>
					<xsl:if test="@Reference_to">
							<xsl:choose>
 								<xsl:when test="id(@Reference_to)/Author">
 									<xsl:for-each select="id(@Reference_to)/Author">
 										<xsl:apply-templates select="Family"/>
 										<xsl:choose>
											<xsl:when test="position()!=last()">
												<xsl:text>, </xsl:text>
											</xsl:when>
										</xsl:choose> 				
									</xsl:for-each>
								</xsl:when>
								<xsl:when test="id(@Reference_to)/Editor">
									<xsl:for-each select="id(@Reference_to)/Editor">
 										<xsl:apply-templates select="Family"/>
 										<xsl:choose>
											<xsl:when test="position()!=last()">
												<xsl:text>, </xsl:text>
											</xsl:when>
										</xsl:choose> 				
									</xsl:for-each>
								</xsl:when>
								<xsl:when test="id(@Reference_to)/Organization">
	 								<xsl:apply-templates select="id(@Reference_to)/Organization"/>			
								</xsl:when>
							</xsl:choose>
 							<xsl:text>, </xsl:text>
 							<xsl:apply-templates select="id(@Reference_to)/Year"/>
 							<xsl:if test="@Page">
 								<xsl:text>, S. </xsl:text>
 								<xsl:apply-templates select="@Page"/>
 							</xsl:if>
 					</xsl:if>
				</blockquote>
 			</xsl:when>
 			<xsl:otherwise> 			
 				<xsl:text>"</xsl:text><xsl:apply-templates/><xsl:text>" </xsl:text>
 				<xsl:if test="@Reference_to">
 						<xsl:text>[</xsl:text>
 						<xsl:choose>
 							<xsl:when test="id(@Reference_to)/Author">
 								<xsl:for-each select="id(@Reference_to)/Author">
 									<xsl:apply-templates select="Family"/>
 									<xsl:choose>
										<xsl:when test="position()!=last()">
											<xsl:text>, </xsl:text>
										</xsl:when>
									</xsl:choose> 				
								</xsl:for-each>
							</xsl:when>
							<xsl:when test="id(@Reference_to)/Editor">
								<xsl:for-each select="id(@Reference_to)/Editor">
 									<xsl:apply-templates select="Family"/>
 									<xsl:choose>
										<xsl:when test="position()!=last()">
											<xsl:text>, </xsl:text>
										</xsl:when>
									</xsl:choose> 				
								</xsl:for-each>
							</xsl:when>
							<xsl:when test="id(@Reference_to)/Organization">
	 							<xsl:apply-templates select="id(@Reference_to)/Organization"/>			
							</xsl:when>
						</xsl:choose>
 						<xsl:text>, </xsl:text>
 						<xsl:apply-templates select="id(@Reference_to)/Year"/>
 						<xsl:if test="@Page">
 							<xsl:text>, S. </xsl:text>
 							<xsl:apply-templates select="@Page"/>
 						</xsl:if>
 						<xsl:text>]</xsl:text>		
 				</xsl:if>
 			</xsl:otherwise>
 		</xsl:choose>
 	</xsl:template>
 	
 	<xsl:template match="Entity">
<!-- vCard oder PCDATA ? -->
		<xsl:choose>
			<xsl:when test="vCard">
				<xsl:value-of select="vCard/FN"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates/>
			</xsl:otherwise>
		</xsl:choose>
 	</xsl:template>
 	
 	<xsl:template match="Code">
 		<xsl:choose>
 			<xsl:when test="@Display='Block'">
				<xsl:choose>
 					<xsl:when test="../../../Example">
 						<div style="text-indent:4em; font-weight:bold; font-family:monospace; font-size:120%;">
 							<xsl:choose>
 								<xsl:when test="CodeElem">
 									<xsl:for-each select="CodeElem">
 										<div>
 											<xsl:choose>
												<xsl:when test="../@ProgrammingLanguage='XML' and ../@Pretty-Print='Yes'">
													<xsl:call-template name="pretty-print">
														<xsl:with-param name="input" select="."/>
													</xsl:call-template>
												</xsl:when>
												<xsl:otherwise>
													<xsl:value-of select="."/>
												</xsl:otherwise>
											</xsl:choose>
 										</div>
 									</xsl:for-each>
								</xsl:when>
							</xsl:choose>
						</div>
 					</xsl:when>
 					<xsl:otherwise> <!-- kein Example -->
 						<xsl:for-each select="CodeElem">
							<div style="font-family:monospace; padding:5px; padding-left:10px; background-color:#cccccc; margin-left:5pt; margin-right:5pt;"> 						
	 							<xsl:choose>
									<xsl:when test="@ProgrammingLanguage='XML' and @Pretty-Print='Yes'">
										<xsl:call-template name="pretty-print">
											<xsl:with-param name="input" select="."/>
										</xsl:call-template>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="."/>
									</xsl:otherwise>
								</xsl:choose>
							</div>
 						</xsl:for-each>
 					</xsl:otherwise>
 				</xsl:choose>
 			</xsl:when>
 			<xsl:otherwise> <!-- Inline - Unterscheidung nach Example entfaellt -->
 				<span style="font-family:monospace; font-size:120%;">
 					<xsl:choose>
						<xsl:when test="@ProgrammingLanguage='XML' and @Pretty-Print='Yes'">
							<xsl:call-template name="pretty-print">
								<xsl:with-param name="input" select="."/>
							</xsl:call-template>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="."/>
						</xsl:otherwise>
					</xsl:choose>
 				</span>
 			</xsl:otherwise>		
 	 	</xsl:choose>
 	</xsl:template>
 	
 	<xsl:template match="List">
 		<xsl:choose>
			<xsl:when test="@Type='Ordered'">
				<xsl:for-each select="Title">
					<br/>
					<xsl:apply-templates select="."/>
				</xsl:for-each>	
				<ol>
					<xsl:apply-templates select="Item"/>
 				</ol>
 			</xsl:when>	
 			<xsl:otherwise>
			<xsl:for-each select="Title">
				<br/>
				<xsl:apply-templates select="."/>
			</xsl:for-each>	
 			<ul>
 				<xsl:apply-templates select="Item"/>
 			</ul>
 			</xsl:otherwise>
 		</xsl:choose>
 	</xsl:template>	
 	
 	<xsl:template match="Item">
		<li>
			<xsl:for-each select="Paragraph">
				<xsl:apply-templates/>
				<xsl:if test="following-sibling::Paragraph">
					<br/>
				</xsl:if>
			</xsl:for-each>
		</li>
	</xsl:template>
	
	<xsl:template match="Formula">
		<xsl:choose>
 			<xsl:when test="@Display='Block'">
 				<div class="FormulaBlock">
 					<xsl:if test="@Id">
 						<xsl:attribute name="id">
 							<xsl:value-of select="@Id"/>
 						</xsl:attribute>
 					</xsl:if>
 					<xsl:copy-of select="node()"/>
 					<xsl:if test="@Id">
 						<span style="margin-left:80%;">
 							<xsl:text>(</xsl:text>
 							<xsl:choose>
 								<xsl:when test="@Information_Link">
 									<a target="_blank">
 										<xsl:attribute name="href">
 											<xsl:value-of select="@Information_Link"/>
 										</xsl:attribute>
 										<xsl:value-of select="@Id"/>
 									</a>
 								</xsl:when>
 								<xsl:when test="@Information_Ref">
 									<a>
 										<xsl:attribute name="href">
 											<xsl:value-of select="@Information_Ref"/>
 										</xsl:attribute>
 										<xsl:value-of select="@Id"/>
 									</a>
 								</xsl:when>
 								<xsl:otherwise>
 									<xsl:value-of select="@Id"/>
 								</xsl:otherwise>
 							</xsl:choose>
 							<xsl:text>)</xsl:text>
 						</span>
 					</xsl:if>
 				</div>
 			</xsl:when>
 			<xsl:otherwise>
 				<span style="font-size:12pt; white-space: nowrap;">
 					<xsl:if test="@Id">
 						<xsl:attribute name="id">
 							<xsl:value-of select="@Id"/>
 						</xsl:attribute>
 					</xsl:if>
 					<xsl:copy-of select="node()"/>
 				</span>
 			</xsl:otherwise>
 		</xsl:choose>
	</xsl:template>
	
<!-- Innerhalb eines LearningObjects werden die Tabellen automatisch durchnummeriert -->
<!-- Attribute werden nach HTML durchgereicht -->
	<xsl:template match="Table">
		<xsl:for-each select="Title">
			<xsl:value-of select="."/>
		<br/>
		</xsl:for-each>
		<table>
		<xsl:for-each select="@Width">
			<xsl:attribute name="width">
				<xsl:value-of select="."/>
			</xsl:attribute>
		</xsl:for-each>
		<xsl:for-each select="@Height">
			<xsl:attribute name="height">
				<xsl:value-of select="."/>
			</xsl:attribute>
		</xsl:for-each>
		<xsl:for-each select="@Border">
			<xsl:attribute name="border">
				<xsl:value-of select="."/>
			</xsl:attribute>
		</xsl:for-each>
		<xsl:if test="Summary">
			<xsl:attribute name="summary">
				<xsl:value-of select="Summary"/>
			</xsl:attribute>
		</xsl:if>
		<xsl:if test="HeaderCaption">
			<caption align="top">
			<xsl:choose>
			<xsl:when test="../@Language='de'">
			<xsl:text>Tabelle </xsl:text>
			</xsl:when>
			<xsl:when test="../@Language='en'">
			<xsl:text>Table </xsl:text>
			</xsl:when>
			</xsl:choose>
			<xsl:number count="Table"/><xsl:text>: </xsl:text>
			<xsl:value-of select="HeaderCaption"/>
			</caption>
		</xsl:if>
		<xsl:if test="FooterCaption">
			<caption align="bottom">
			<xsl:value-of select="FooterCaption"/>
			</caption>
		</xsl:if>
		<xsl:for-each select="TableRow">
			<tr>
				<xsl:for-each select="TableData">
					<td>
						<xsl:apply-templates/>
					</td>
				</xsl:for-each>
			</tr>
		</xsl:for-each>
		</table>
	</xsl:template>
	
	<xsl:template match="Glossary">
		<xsl:variable name="gloss" select="concat(string(../MetaData/General/Identifier/@Entry),'-','gloss','.xhtml')"/>
		<xsl:result-document href="{$gloss}">
			<html>
				<head>
					<title>
						<xsl:choose>
							<xsl:when test="../MetaData/General/Language='de'">
								<xsl:value-of select="concat(string(../MetaData/General/Title),' - ','Glossar')"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="concat(string(../MetaData/General/Title),' - ','Glossary')"/>
							</xsl:otherwise>
						</xsl:choose>
					</title>
				</head>	
				<body>
					<xsl:choose>
						<xsl:when test="../MetaData/General/Language='de'">
							<h1>Glossar</h1>
						</xsl:when>
						<xsl:when test="../MetaData/General/Language='en'">
							<h1>Glossary</h1>
						</xsl:when>
					</xsl:choose>
					<table width="90%">
						<xsl:for-each select="GlossaryItem">
							<xsl:sort select="GlossaryTerm"/>
							<tr>
								<xsl:attribute name="id">
									<xsl:value-of select="GlossaryTerm/@Definition"/>
								</xsl:attribute>
								<xsl:for-each select="GlossaryTerm">
									<td valign="top"><xsl:value-of select="."/></td>
								</xsl:for-each>
								<xsl:for-each select="DefinitionList">
									<td>
										<xsl:for-each select="Definition">
											<xsl:apply-templates/>
										</xsl:for-each>
									</td>
								</xsl:for-each>
								<xsl:for-each select="Definition">
									<td valign="top"><xsl:apply-templates select="."/></td>
								</xsl:for-each>
							</tr>
						</xsl:for-each>
					</table>
				</body>
			</html>
		</xsl:result-document>
	</xsl:template>
	
	<xsl:template match="GlossaryTerm">
		<xsl:apply-templates/>
		<span style="vertical-align:super;font-size:small;color:red">G</span>
		<span style="background-color:yellow"><b>HIER VRI LINK INS GLOSSAR EINFUEGEN!</b></span>
	</xsl:template>
	
	<xsl:template match="Definition">
		<xsl:for-each select="Paragraph">
			<xsl:apply-templates/>
			<xsl:if test="following-sibling::Paragraph">
				<br/>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template match="Reference">
		<xsl:choose>
			<xsl:when test="@Type='BibliographyEntry'">
				<xsl:choose>
 					<xsl:when test="id(@Reference_to)/Author">
 						<xsl:for-each select="id(@Reference_to)/Author">
 							<xsl:apply-templates select="Family"/>
 							<xsl:choose>
								<xsl:when test="position()!=last()">
									<xsl:text>, </xsl:text>
								</xsl:when>
							</xsl:choose> 				
						</xsl:for-each>
					</xsl:when>
					<xsl:when test="id(@Reference_to)/Editor">
						<xsl:for-each select="id(@Reference_to)/Editor">
							<xsl:apply-templates select="Family"/>
 							<xsl:choose>
								<xsl:when test="position()!=last()">
									<xsl:text>, </xsl:text>
								</xsl:when>
							</xsl:choose> 				
						</xsl:for-each>
						<xsl:text> (Hrsg.)</xsl:text>
					</xsl:when>
					<xsl:when test="id(@Reference_to)/Organization">
						<xsl:for-each select="id(@Reference_to)/Organization">
							<xsl:apply-templates select="."/>
 							<xsl:choose>
								<xsl:when test="position()!=last()">
									<xsl:text>, </xsl:text>
								</xsl:when>
							</xsl:choose> 				
						</xsl:for-each>
						<xsl:text>, </xsl:text>
						<xsl:apply-templates select="id(@Reference_to)/Title"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="id(@Reference_to)/Year">
					<xsl:text>, </xsl:text>
 					<xsl:apply-templates select="id(@Reference_to)/Year"/>
 				</xsl:if>
 				<xsl:if test="@Page">
 					<xsl:text>, S. </xsl:text>
 					<xsl:apply-templates select="@Page"/>
 				</xsl:if>
 			</xsl:when>
 			<xsl:when test="@Type='LearningObject'">
<!-- Verzweigung: Je nach AggregationLevel wird anders verfahren -->
 				<xsl:choose>
 					<xsl:when test="id(@Reference_to)/../@AggregationLevel='1'">
<!-- Level 1-LearningObjects --> 
<!-- Erster Schritt: Level 1-LO, auf die verwiesen wird, erhalten eine eigene XHTML-Datei -->
 						<xsl:variable name="LO1" select="concat(string(@Reference_to),'.xhtml')"/>
 						<xsl:result-document href="{$LO1}">
 							<html>
 								<head>
 									<title>
 										<xsl:value-of select="id(@Reference_to)/../Title"/>
 									</title>
 								</head>
 								<body>
<!-- Hier muss unterschieden werden - je nach Dateiformat kann img oder a gewaehlt werden -->
									<xsl:choose>
										<xsl:when test="id(@Reference_to)/../../Technical/@Format='image-gif'">
<!-- Einbinden der LOs, die GIF-Grafiken sind - per img-Tag -->	
											<img>
 												<xsl:attribute name="src">
 													<xsl:value-of select="id(@Reference_to)/../../Technical/Location"/>
 												</xsl:attribute>
 											</img>
<!-- Ausgabe des Titels und der Description -->																
		 									<div style="font-family:verdana,arial,sans-serif; font-weight:bold; font-size:smaller;">
												<xsl:choose>
													<xsl:when test="id(@Reference_to)/../Language='de'">
														<xsl:text>Abbildung </xsl:text>
													</xsl:when>
													<xsl:otherwise>
														<xsl:text>Figure </xsl:text>
													</xsl:otherwise>
												</xsl:choose>
												<xsl:number count="LearningObject"/>
												<xsl:text>: </xsl:text>
												<xsl:value-of select="id(@Reference_to)/../Title"/>
											</div>
											<div style="font-family:verdana,arial,sans-serif; font-size:smaller;">
												<xsl:apply-templates select="id(@Reference_to)/../Description"/>
											</div> 											
										</xsl:when>
										<xsl:when test="id(@Reference_to)/../../Technical/@Format='image-jpeg'">
<!-- Einbinden der LOs, die JPEG-Grafiken sind - per img-Tag -->	
											<img>
 												<xsl:attribute name="src">
 													<xsl:value-of select="id(@Reference_to)/../../Technical/Location"/>
 												</xsl:attribute>
 											</img>
<!-- Ausgabe des Titels und der Description -->																
		 									<div style="font-family:verdana,arial,sans-serif; font-weight:bold; font-size:smaller;">
												<xsl:choose>
													<xsl:when test="id(@Reference_to)/../Language='de'">
														<xsl:text>Abbildung </xsl:text>
													</xsl:when>
													<xsl:otherwise>
														<xsl:text>Figure </xsl:text>
													</xsl:otherwise>
												</xsl:choose>
												<xsl:number count="LearningObject"/>
												<xsl:text>: </xsl:text>
												<xsl:value-of select="id(@Reference_to)/../Title"/>
											</div>
											<div style="font-family:verdana,arial,sans-serif; font-size:smaller;">
												<xsl:apply-templates select="id(@Reference_to)/../Description"/>
											</div>
										</xsl:when>
										<xsl:when test="id(@Reference_to)/../../Technical/@Format='image-png'">
<!-- Einbinden der LOs, die PNG-Grafiken sind - per img-Tag -->	
											<img>
 												<xsl:attribute name="src">
 													<xsl:value-of select="id(@Reference_to)/../../Technical/Location"/>
 												</xsl:attribute>
 											</img>
<!-- Ausgabe des Titels und der Description -->																
		 									<div style="font-family:verdana,arial,sans-serif; font-weight:bold; font-size:smaller;">
												<xsl:choose>
													<xsl:when test="id(@Reference_to)/../Language='de'">
														<xsl:text>Abbildung </xsl:text>
													</xsl:when>
													<xsl:otherwise>
														<xsl:text>Figure </xsl:text>
													</xsl:otherwise>
												</xsl:choose>
												<xsl:number count="LearningObject"/>
												<xsl:text>: </xsl:text>
												<xsl:value-of select="id(@Reference_to)/../Title"/>
											</div>
											<div style="font-family:verdana,arial,sans-serif; font-size:smaller;">
												<xsl:apply-templates select="id(@Reference_to)/../Description"/>
											</div>
										</xsl:when>
										<xsl:when test="id(@Reference_to)/../../Technical/@Format='image-svg-xml'">
											<xsl:copy-of select="document(id(@Reference_to)/../../Technical/Location)/*"/>
<!-- Ausgabe des Titels und der Description -->																
		 									<div style="font-family:verdana,arial,sans-serif; font-weight:bold; font-size:smaller;">
												<xsl:choose>
													<xsl:when test="id(@Reference_to)/../Language='de'">
														<xsl:text>Abbildung </xsl:text>
													</xsl:when>
													<xsl:otherwise>
														<xsl:text>Figure </xsl:text>
													</xsl:otherwise>
												</xsl:choose>
												<xsl:number count="LearningObject"/>
												<xsl:text>: </xsl:text>
												<xsl:value-of select="id(@Reference_to)/../Title"/>
											</div>
											<div style="font-family:verdana,arial,sans-serif; font-size:smaller;">
												<xsl:apply-templates select="id(@Reference_to)/../Description"/>
											</div>
										</xsl:when>
										<xsl:otherwise>
<!-- LOs, die keine Grafiken sind, werden per a eingebunden -->
											<a class="Image">
 												<xsl:attribute name="href">
 													<xsl:value-of select="id(@Reference_to)/../../Technical/Location"/>
 												</xsl:attribute>
 												<xsl:value-of select="id(@Reference_to)/../Title"/>
 											</a>
 											<div style="font-family:verdana,arial,sans-serif; font-size:smaller;">
												<xsl:apply-templates select="id(@Reference_to)/../Description"/>
											</div>							
										</xsl:otherwise>
									</xsl:choose> 		
 								</body>
 							</html>
 						</xsl:result-document>
<!-- Zweiter Schritt: Einbau der Referenz auf die soeben erzeugte XHTML-Datei --> 						
						<a target="_blank">
							<xsl:attribute name="href">
								<xsl:value-of select="concat(string(@Reference_to),'.xhtml')"/>
							</xsl:attribute>									
							<xsl:text>&#187; </xsl:text>
							<xsl:value-of select="id(@Reference_to)/../Title"/>
						</a>								
 					</xsl:when>
<!-- Ende von Behandlung von Level 1 LOs -->
					<xsl:otherwise>
<!-- Level 2 oder 3 LOs, auf die referenziert wird -->
						<span style="font-style:italic;color:red">
 							<xsl:text>&#187; </xsl:text>
 								<xsl:value-of select="id(@Reference_to)/../Title"/>
 							</span>
					</xsl:otherwise> 					
<!-- Ende von Behandlung von Level 2 oder 3 LOs -->					
 				</xsl:choose>
 			</xsl:when>
<!-- Ende der Verarbeitung von LearningObjects -->
 			<xsl:when test="@Type='Example'">
 				<span style="font-style:italic;color:blue">
					<xsl:text>&#187; </xsl:text>
					<xsl:choose>
						<xsl:when test="../@Language='de'">
							<xsl:text>Beispiel</xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text>Example</xsl:text>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:text>: </xsl:text>
					<xsl:value-of select="translate(@Reference_to,'_',' ')"/>
					<xsl:apply-templates/>
				</span>
 			</xsl:when>
 			<xsl:otherwise>
<!-- Referenz auf eine Stelle im Text --> 			
				<xsl:text>&#187;</xsl:text>
				<xsl:apply-templates/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="RefTarget">
		<span>
		<xsl:attribute name="id">
			<xsl:value-of select="@Id"/>
		</xsl:attribute>
		<xsl:apply-templates/>
		</span>
	</xsl:template>
	
	<xsl:template match="Examples">
		<p>
			<xsl:apply-templates/>
		</p>
	</xsl:template>
	
	<xsl:template match="Example">
		<div style="text-indent:3em; font-weight:bold; margin:15pt;">
			<xsl:choose>
				<xsl:when test="//MetaData/General/Language='de'">
					<xsl:text>Beispiel </xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>Example</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:number count="Example" level="any"/>
			<xsl:text>: </xsl:text>
			<xsl:value-of select="translate(@Id,'_',' ')"/>
			<xsl:text> </xsl:text>
		</div>
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="Example/*">
		<div style="text-indent:4em; font-weight:bold;">
			<xsl:choose>
				<xsl:when test="../@Status='Ill-formed'">
					<xsl:text>* </xsl:text>
				</xsl:when>
				<xsl:when test="../@Status='Questionable'">
					<xsl:text>? </xsl:text>
				</xsl:when>
			</xsl:choose>
			<xsl:apply-templates/>
		</div>
	</xsl:template>
	
	<xsl:template match="Gloss">
		<span style="text-indent:3em;"><xsl:apply-templates/></span>
	</xsl:template>
	
	<xsl:template match="Formalisation">
		<span style="text-indent:3em;"><xsl:apply-templates/></span>
	</xsl:template>
	
	<xsl:template match="Transcription">
		<span style="text-indent:3em;"><xsl:apply-templates/></span>
	</xsl:template>
	
	<xsl:template match="Translation">
		<span style="text-indent:3em;"><xsl:apply-templates/></span>
	</xsl:template>
	
	<xsl:template match="Bibliography">
		<xsl:variable name="bib" select="concat(string(../MetaData/General/Identifier/@Entry),'-','bib','.xhtml')"/>
		<xsl:result-document href="{$bib}">
			<html>
				<head>
					<title>
						<xsl:choose>
							<xsl:when test="../MetaData/General/Language='de'">
								<xsl:value-of select="concat(string(../MetaData/General/Title),' - ','Literaturangaben')"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="concat(string(../MetaData/General/Title),' - ','Bibliography')"/>
							</xsl:otherwise>
						</xsl:choose>
					</title>
				</head>	
				<body>
					<xsl:choose>
						<xsl:when test="../MetaData/General/Language='de'">
							<h1>Literaturangaben</h1>
						</xsl:when>
						<xsl:when test="../MetaData/General/Language='en'">
							<h1>Bibliography</h1>
						</xsl:when>
					</xsl:choose>
					<xsl:if test="Bibitem/@Type='Article'">
						<xsl:choose>
							<xsl:when test="../MetaData/General/Language='de'">
								<h3>Artikel</h3>
							</xsl:when>
							<xsl:when test="../MetaData/General/Language='en'">
								<h3>Articles</h3>
							</xsl:when>
						</xsl:choose>
						<xsl:for-each select="Bibitem[@Type='Article']">
							<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
							<p>
								<xsl:apply-templates select="."/>
							</p>
						</xsl:for-each>
					</xsl:if>
					<xsl:if test="Bibitem/@Type='AV'">
						<h3>AV</h3>
						<xsl:for-each select="Bibitem[@Type='AV']">
							<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
							<p>
								<xsl:apply-templates select="."/>
							</p>
						</xsl:for-each>
					</xsl:if>
					<xsl:if test="Bibitem/@Type='Book'">
						<xsl:choose>
							<xsl:when test="../MetaData/General/Language='de'">
								<h3>Bücher</h3>
							</xsl:when>
							<xsl:when test="../MetaData/General/Language='en'">
								<h3>Books</h3>
							</xsl:when>
						</xsl:choose>
						<xsl:for-each select="Bibitem[@Type='Book']">
							<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
							<p>
								<xsl:apply-templates select="."/>
							</p>
						</xsl:for-each>
					</xsl:if>
					<xsl:if test="Bibitem/@Type='Dissertation'">
						<h3>Dissertation</h3>
						<xsl:for-each select="Bibitem[@Type='Dissertation']">
							<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
							<p>
								<xsl:apply-templates select="."/>
							</p>
						</xsl:for-each>
					</xsl:if>
					<xsl:if test="Bibitem/@Type='Inbook'">
						<xsl:choose>
							<xsl:when test="../MetaData/General/Language='de'">
								<h3>Kapitel</h3>
							</xsl:when>
							<xsl:when test="../MetaData/General/Language='en'">
								<h3>Inbook</h3>
							</xsl:when>
						</xsl:choose>
						<xsl:for-each select="Bibitem[@Type='Inbook']">
							<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
							<p>
								<xsl:apply-templates select="."/>
							</p>
						</xsl:for-each>
					</xsl:if>
					<xsl:if test="Bibitem/@Type='Incollection'">
						<xsl:choose>
							<xsl:when test="../MetaData/General/Language='de'">
								<h3>Artikel</h3>
							</xsl:when>
							<xsl:when test="../MetaData/General/Language='en'">
								<h3>Incollection</h3>
							</xsl:when>
						</xsl:choose>
						<xsl:for-each select="Bibitem[@Type='Incollection']">
							<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
							<p>
								<xsl:apply-templates select="."/>
							</p>
						</xsl:for-each>
					</xsl:if>
					<xsl:if test="Bibitem/@Type='Inproceedings'">
						<xsl:choose>
							<xsl:when test="../MetaData/General/Language='de'">
								<h3>Beiträge</h3>
							</xsl:when>
							<xsl:when test="../MetaData/General/Language='en'">
								<h3>Inproceedings</h3>
							</xsl:when>
						</xsl:choose>
						<xsl:for-each select="Bibitem[@Type='Inproceedings']">
							<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
							<p>
								<xsl:apply-templates select="."/>
							</p>
						</xsl:for-each>
					</xsl:if>
					<xsl:if test="Bibitem/@Type='Internet'">
						<h3>Internet</h3>
						<xsl:for-each select="Bibitem[@Type='Internet']">
							<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
							<p>
								<xsl:apply-templates select="."/>
							</p>
						</xsl:for-each>
					</xsl:if>
					<xsl:if test="Bibitem/@Type='Journalarticle'">
						<xsl:choose>
							<xsl:when test="../MetaData/General/Language='de'">
								<h3>Zeitschriftenartikel</h3>
							</xsl:when>
							<xsl:when test="../MetaData/General/Language='en'">
								<h3>Journalarticle</h3>
							</xsl:when>
						</xsl:choose>
						<xsl:for-each select="Bibitem[@Type='Journalarticle']">
							<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
							<p>
								<xsl:apply-templates select="."/>
							</p>
						</xsl:for-each>
					</xsl:if>
					<xsl:if test="Bibitem/@Type='Manual'">
						<xsl:choose>
							<xsl:when test="../MetaData/General/Language='de'">
								<h3>Handbuch</h3>
							</xsl:when>
							<xsl:when test="../MetaData/General/Language='en'">
								<h3>Manual</h3>
							</xsl:when>
						</xsl:choose>
						<xsl:for-each select="Bibitem[@Type='Manual']">
							<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
							<p>
								<xsl:apply-templates select="."/>
							</p>
						</xsl:for-each>
					</xsl:if>
					<xsl:if test="Bibitem/@Type='Mastersthesis'">
						<xsl:choose>
							<xsl:when test="../MetaData/General/Language='de'">
								<h3>Diplom- oder Magisterarbeiten</h3>
							</xsl:when>
							<xsl:when test="../MetaData/General/Language='en'">
								<h3>Mastersthesis</h3>
							</xsl:when>
						</xsl:choose>
						<xsl:for-each select="Bibitem[@Type='Mastersthesis']">
							<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
							<p>
								<xsl:apply-templates select="."/>
							</p>
						</xsl:for-each>
					</xsl:if>
					<xsl:if test="Bibitem/@Type='Newspaperarticle'">
						<xsl:choose>
							<xsl:when test="../MetaData/General/Language='de'">
								<h3>Zeitungsartikel</h3>
							</xsl:when>
							<xsl:when test="../MetaData/General/Language='en'">
								<h3>Newspaperarticle</h3>
							</xsl:when>
						</xsl:choose>
						<xsl:for-each select="Bibitem[@Type='Newspaperarticle']">
							<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
							<p>
								<xsl:apply-templates select="."/>
							</p>
						</xsl:for-each>
					</xsl:if>
					<xsl:if test="Bibitem/@Type='Phdthesis'">
						<xsl:choose>
							<xsl:when test="../MetaData/General/Language='de'">
								<h3>Doktorarbeiten</h3>
							</xsl:when>
							<xsl:when test="../MetaData/General/Language='en'">
								<h3>Phdthesis</h3>
							</xsl:when>
						</xsl:choose>
						<xsl:for-each select="Bibitem[@Type='Phdthesis']">
							<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
							<p>
								<xsl:apply-templates select="."/>
							</p>
						</xsl:for-each>
					</xsl:if>
					<xsl:if test="Bibitem/@Type='Proceedings'">
						<xsl:choose>
							<xsl:when test="../MetaData/General/Language='de'">
								<h3>Protokolle und Berichte</h3>
							</xsl:when>
							<xsl:when test="../MetaData/General/Language='en'">
								<h3>Proceedings</h3>
							</xsl:when>
						</xsl:choose>
						<xsl:for-each select="Bibitem[@Type='Proceedings']">
							<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
							<p>
								<xsl:apply-templates select="."/>
							</p>
						</xsl:for-each>
					</xsl:if>
					<xsl:if test="Bibitem/@Type='Techreport'">
						<xsl:choose>
							<xsl:when test="../MetaData/General/Language='de'">
								<h3>Technische Reports</h3>
							</xsl:when>
							<xsl:when test="../MetaData/General/Language='en'">
								<h3>Techreport</h3>
							</xsl:when>
						</xsl:choose>
						<xsl:for-each select="Bibitem[@Type='Techreport']">
							<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
							<p>
								<xsl:apply-templates select="."/>
							</p>
						</xsl:for-each>
					</xsl:if>
					<xsl:if test="Bibitem/@Type='Unpublished'">
						<xsl:choose>
							<xsl:when test="../MetaData/General/Language='de'">
								<h3>Unveröffentlicht</h3>
							</xsl:when>
							<xsl:when test="../MetaData/General/Language='en'">
								<h3>Unpublished</h3>
							</xsl:when>
						</xsl:choose>
						<xsl:for-each select="Bibitem[@Type='Unpublished']">
							<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
							<p>
								<xsl:apply-templates select="."/>
							</p>
						</xsl:for-each>
					</xsl:if>
				</body>
			</html>
		</xsl:result-document>	
	</xsl:template>
	
	<xsl:template match="Bibitem">
		<a>
			<xsl:attribute name="id">
				<xsl:value-of select="@Label"/>
			</xsl:attribute>
			<xsl:choose>
				<xsl:when test="Author">
					<xsl:for-each select="Author">
						<xsl:apply-templates select="Family"/>
						<xsl:if test="Given | Other | Suffix">
							<xsl:text>, </xsl:text>
							<xsl:apply-templates select="Given"/>
							<xsl:if test="Other">
								<xsl:text> </xsl:text>
								<xsl:apply-templates select="Other"/>
							</xsl:if>
							<xsl:if test="Suffix">
								<xsl:text>, </xsl:text>
								<xsl:apply-templates select="Suffix"/>
							</xsl:if>
						</xsl:if>
						<xsl:choose>
							<xsl:when test="position()=last()">
								<xsl:text>, </xsl:text>
							</xsl:when>
							<xsl:otherwise>
								<xsl:text>/</xsl:text>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
				</xsl:when>
				<xsl:when test="Editor">
					<xsl:for-each select="Editor">
						<xsl:apply-templates select="Family"/>
						<xsl:if test="Given | Other | Suffix">
							<xsl:text>, </xsl:text>
							<xsl:apply-templates select="Given"/>
							<xsl:if test="Other">
								<xsl:text> </xsl:text>
								<xsl:apply-templates select="Other"/>
							</xsl:if>
							<xsl:if test="Suffix">
								<xsl:text>, </xsl:text>
								<xsl:apply-templates select="Suffix"/>
							</xsl:if>
						</xsl:if>
						<xsl:choose>
							<xsl:when test="position()=last()">
								<xsl:choose>
									<xsl:when test="ancestor::LearningObject[1]/MetaData/General/Language='de'">
										<xsl:text> (Hrsg.), </xsl:text>
									</xsl:when>
									<xsl:otherwise>
										<xsl:text> (Ed.), </xsl:text>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:when>
							<xsl:otherwise>
								<xsl:text>/</xsl:text>
							</xsl:otherwise>
						</xsl:choose>			
					</xsl:for-each>
				</xsl:when>
				<xsl:when test="Organization">
					<xsl:apply-templates select="Organization"/>
					<xsl:text>, </xsl:text>
				</xsl:when>
			</xsl:choose>	
		</a>
		<xsl:text> "</xsl:text>
		<xsl:choose>
			<xsl:when test="@Type='Internet'">
				<xsl:value-of select="Title"/>
				<xsl:text>".</xsl:text>
				<br/>
				<xsl:if test="Edition">
					<xsl:value-of select="Edition"/>
					<br/>
				</xsl:if>
				<xsl:if test="Publisher">
					<xsl:apply-templates select="Publisher"/>
					<xsl:text>, </xsl:text>	
				</xsl:if>
				<xsl:for-each select="URL">
					<a>
						<xsl:attribute name="href">
							<xsl:value-of select="."/>
						</xsl:attribute>
						<xsl:value-of select="."/>
					</a>
					<xsl:if test="position()!=last()">
						<xsl:text>, </xsl:text>
					</xsl:if>
				</xsl:for-each>
				<xsl:if test="Year">
					<xsl:text>, </xsl:text>
					<xsl:value-of select="Year"/>
				</xsl:if>
				<xsl:text>.</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="Title"/>
				<xsl:if test="Booktitle">
					<xsl:text>in: </xsl:text>
					<xsl:value-of select="Booktitle"/>
				</xsl:if>
				<xsl:text>".</xsl:text>
				<br/>
				<xsl:if test="Edition">
					<xsl:value-of select="Edition"/>
					<br/>
				</xsl:if>
				<xsl:if test="Organization">
					<xsl:apply-templates select="Organization"/>
					<xsl:text>, </xsl:text>
				</xsl:if>
				<xsl:if test="Publisher">
					<xsl:apply-templates select="Publisher"/>
					<xsl:text>, </xsl:text>	
				</xsl:if>
				<xsl:if test="Address">
					<xsl:value-of select="Address"/>
					<xsl:text>, </xsl:text>
				</xsl:if>
				<xsl:value-of select="Year"/>
				<xsl:text>.</xsl:text>
			</xsl:otherwise>
		</xsl:choose>		
	</xsl:template>
	
	<xsl:template name="pretty-print">
		<xsl:analyze-string select="." regex="[&lt;&gt;]">
			<xsl:matching-substring>
				<span style="color:blue">
					<xsl:value-of select="."/>
				</span>
			</xsl:matching-substring>
			<xsl:non-matching-substring>
				<xsl:call-template name="name">
					<xsl:with-param name="input" select="."/>
				</xsl:call-template>	
			</xsl:non-matching-substring>
		</xsl:analyze-string>
	</xsl:template>
	
	<xsl:template name="name">
		<xsl:param name="input"/>
		<xsl:analyze-string select="$input" regex="([#!][A-Z]*)">
			<xsl:matching-substring>
				<span style="color:red">
					<xsl:value-of select="regex-group(1)"/>
				</span>
			</xsl:matching-substring>
			<xsl:non-matching-substring>
				<xsl:value-of select="."/>
			</xsl:non-matching-substring>
		</xsl:analyze-string>
	</xsl:template>
	
	<!-- nur fuer interne Testzwecke -->
	
	<xsl:template match="Test">
		<xsl:if test="TestItem">
			<xsl:choose>
				<xsl:when test="../MetaData/General/Language='de'">
					<h3>Übungsaufgaben</h3>
				</xsl:when>
				<xsl:otherwise>
					<h3>Exercise</h3>
				</xsl:otherwise>
			</xsl:choose>				
		</xsl:if>
		<ol>
			<xsl:for-each select="TestItem">
				<li><xsl:apply-templates select="Question"/></li>
			</xsl:for-each>
		</ol>
	</xsl:template>
	
	<xsl:template match="Comment">
		<span style="background-color:yellow">>
			<xsl:apply-templates/>
			<xsl:if test="@Annotator">
				<b><xsl:text> Anmerkung von: </xsl:text>
				<xsl:value-of select="@Annotator"/></b>
			</xsl:if>
		</span>
	</xsl:template>

</xsl:stylesheet>